%DHTRANS    Denavit-Hartenberg transformation
% takes the four Denavit-Hartenberg link parameters and constructs a 
% transformation matrix representing the coordinate frame at the end of the link
%
% Syntax:  T = DHtrans(theta, offset, length, twist)
%
% Inputs:
%    theta - angle between the links
%    offset - link offset
%    length - link length
%    twist - twist angle
%
% Outputs:
%    T - Denavit-Hartenberg transformation matrix
%
% Other m-files required: rotx.m, rotx.m, trans.m
%
% See also: ROTX, ROTZ, TRANS

% Author: Travis Hydzik
% Last revision: 19 October 2004

function T = DHtrans(theta, offset, length, twist)
    
    T = rotz(theta)*trans(0,0,offset)*trans(length,0,0)*rotx(twist);